<?php

   // Replace 'your_database.db' with the path to your SQLite database file
   $database = new SQLite3('../database/digital.db');
    
    // Function to create tables if they don't exist
    function createTables($database) {
        $createButtonsTable = "CREATE TABLE IF NOT EXISTS buttons (
            id_button INTEGER PRIMARY KEY AUTOINCREMENT,
            icon TEXT NOT NULL,
            label TEXT NOT NULL,
            tags TEXT NOT NULL,
            url TEXT NOT NULL,
            id_group INTEGER NOT NULL
        );";
        
        $createGroupsTable = "CREATE TABLE IF NOT EXISTS groups (
            id_group INTEGER PRIMARY KEY AUTOINCREMENT,
            name TEXT NOT NULL,
            color TEXT NOT NULL
        );";
        
        $createUsersTable = "CREATE TABLE IF NOT EXISTS users (
            id_user INTEGER PRIMARY KEY AUTOINCREMENT,
            username TEXT NOT NULL,
            password TEXT NOT NULL,
            created_at DATETIME DEFAULT CURRENT_TIMESTAMP
        );";
        
        $database->exec($createButtonsTable);
        $database->exec($createGroupsTable);
        $database->exec($createUsersTable);
    }
    
    
    //buttons fuctions:
    
    // Function to insert data into the buttons table
    function insertButtonData($conn, $label, $tags, $url, $icon, $id_group) {
        $stmt = $conn->prepare("INSERT INTO buttons (icon, label, tags, url, id_group) VALUES (?, ?, ?, ?, ?)");
        $stmt->bindValue(1, $icon);
        $stmt->bindValue(2, $label);
        $stmt->bindValue(3, $tags);
        $stmt->bindValue(4, $url);
        $stmt->bindValue(5, $id_group);
        $stmt->execute();
    }
    
    // Function to update data in the buttons table
    function updateButtonData($conn, $label, $url, $icon, $id_group, $tags, $id_button) {
        $stmt = $conn->prepare("UPDATE buttons SET icon=?, label=?, tags=?, url=?, id_group=? WHERE id_button=?;");
        $stmt->bindValue(1, $icon);
        $stmt->bindValue(2, $label);
        $stmt->bindValue(3, $tags);
        $stmt->bindValue(4, $url);
        $stmt->bindValue(5, $id_group);
        $stmt->bindValue(6, $id_button);
        $stmt->execute();
    }
    
    // Function to delete data from the buttons table
    function deleteButtonData($conn, $buttonId) {
        
        try{
            $stmt = $conn->prepare("DELETE FROM buttons WHERE id_button=?;");
           $stmt->bindValue(1, $buttonId);
            $stmt->execute();
        }catch (PDOException $e) {
            echo "Connection failed: 2 " . $e->getMessage();
        }
    }
    
    
    //groups fuctions:
    
    function insertGroupData($conn, $name, $color) {
        $stmt = $conn->prepare("INSERT INTO groups (name, color) VALUES (?, ?)");
        $stmt->bindValue(1, $name);
        $stmt->bindValue(2, $color);
        $stmt->execute();
    }
    
    // Function to update data in the groups table
    function updateGroupData($conn, $name, $color, $id_group) {
        $stmt = $conn->prepare("UPDATE groups SET name=?, color=? WHERE id_group=?;");
        $stmt->bindValue(1, $name);
        $stmt->bindValue(2, $color);
        $stmt->bindValue(3, $id_group);
        $stmt->execute();
    }
    
     // Function to delete data from the groups table
    function deleteGroupData($conn, $groupId) {
        $stmt = $conn->prepare("DELETE FROM groups WHERE id_group=?;");
        $stmt->bindValue(1, $groupId);
        $stmt->execute();
    }
    
    
    //users fuctions:
    
    // Function to insert data into the users table
    function insertUserData($conn, $param_username, $param_password ) {
        $stmt = $conn->prepare("INSERT INTO users (username, password) VALUES (?, ?)");
        $stmt->bindValue(1, $param_username);
        $stmt->bindValue(2, $param_password);       
        $stmt->execute();
    }
    
    // Function to update data in the users table
    function updateUserData($conn, $username, $password, $id_user) {
        $stmt = $conn->prepare("UPDATE users SET username=?, password=? WHERE id_user=?;");
        $stmt->bindValue(1, $username);
        $stmt->bindValue(2, $password);        
        $stmt->bindValue(3, $id_user);
        $stmt->execute();
    }
    
    // Function to delete data from the users table
    function deleteUserData($conn, $id_user) {
        $stmt = $conn->prepare("DELETE FROM users WHERE id_user=?;");
        $stmt->bindValue(1, $id_user);
        $stmt->execute();
    }
    
    
    
    // Call the functions to create and insert data into the tables
    createTables($database);
    // insertButtonData($database);
    // insertGroupsData($database);
    // insertUsersData($database);
   
    
    // Close the database connection
    $database->close();
    
?>
